/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.bi.pigBreed.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.modular.bi.pigBreed.entity.PigBreed;
import vip.xiaonuo.modular.bi.pigBreed.mapper.PigBreedMapper;
import vip.xiaonuo.modular.bi.pigBreed.param.PigBreedAddParam;
import vip.xiaonuo.modular.bi.pigBreed.param.PigBreedEditParam;
import vip.xiaonuo.modular.bi.pigBreed.param.PigBreedIdParam;
import vip.xiaonuo.modular.bi.pigBreed.param.PigBreedPageParam;
import vip.xiaonuo.modular.bi.pigBreed.service.PigBreedService;

import java.util.List;

/**
 * 配种信息Service接口实现类
 *
 * @author wang
 * @date  2023/12/06 15:27
 **/
@Service
public class PigBreedServiceImpl extends ServiceImpl<PigBreedMapper, PigBreed> implements PigBreedService {

    @Override
    public Page<PigBreed> page(PigBreedPageParam pigBreedPageParam) {
        QueryWrapper<PigBreed> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(pigBreedPageParam.getFemaleCode())) {
            queryWrapper.lambda().like(PigBreed::getFemaleCode, pigBreedPageParam.getFemaleCode());
        }
        if(ObjectUtil.isNotEmpty(pigBreedPageParam.getStartCreateDate()) && ObjectUtil.isNotEmpty(pigBreedPageParam.getEndCreateDate())) {
            queryWrapper.lambda().between(PigBreed::getCreateDate, pigBreedPageParam.getStartCreateDate(), pigBreedPageParam.getEndCreateDate());
        }
        if(ObjectUtil.isAllNotEmpty(pigBreedPageParam.getSortField(), pigBreedPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(pigBreedPageParam.getSortOrder());
            queryWrapper.orderBy(true, pigBreedPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(pigBreedPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(PigBreed::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PigBreedAddParam pigBreedAddParam) {
        PigBreed pigBreed = BeanUtil.toBean(pigBreedAddParam, PigBreed.class);
        this.save(pigBreed);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PigBreedEditParam pigBreedEditParam) {
        PigBreed pigBreed = this.queryEntity(pigBreedEditParam.getId());
        BeanUtil.copyProperties(pigBreedEditParam, pigBreed);
        this.updateById(pigBreed);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PigBreedIdParam> pigBreedIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(pigBreedIdParamList, PigBreedIdParam::getId));
    }

    @Override
    public PigBreed detail(PigBreedIdParam pigBreedIdParam) {
        return this.queryEntity(pigBreedIdParam.getId());
    }

    @Override
    public PigBreed queryEntity(Integer id) {
        PigBreed pigBreed = this.getById(id);
        if(ObjectUtil.isEmpty(pigBreed)) {
            throw new CommonException("配种信息不存在，id值为：{}", id);
        }
        return pigBreed;
    }
}
