/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.bi.pigfat.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.common.pojo.CommonValidList;
import vip.xiaonuo.modular.bi.pigfat.entity.PigFat;
import vip.xiaonuo.modular.bi.pigfat.param.PigFatAddParam;
import vip.xiaonuo.modular.bi.pigfat.param.PigFatEditParam;
import vip.xiaonuo.modular.bi.pigfat.param.PigFatIdParam;
import vip.xiaonuo.modular.bi.pigfat.param.PigFatPageParam;
import vip.xiaonuo.modular.bi.pigfat.service.PigFatService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 肥猪信息控制器
 *
 * @author wang
 * @date  2023/12/18 09:20
 */
@Api(tags = "肥猪信息控制器")
@ApiSupport(author = "SNOWY_TEAM", order = 1)
@RestController
@Validated
public class PigFatController {

    @Resource
    private PigFatService pigFatService;

    /**
     * 获取肥猪信息分页
     *
     * @author wang
     * @date  2023/12/18 09:20
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取肥猪信息分页")
    @SaCheckPermission("/bi/pigfat/page")
    @GetMapping("/bi/pigfat/page")
    public CommonResult<Page<PigFat>> page(PigFatPageParam pigFatPageParam) {
        return CommonResult.data(pigFatService.page(pigFatPageParam));
    }

    /**
     * 添加肥猪信息
     *
     * @author wang
     * @date  2023/12/18 09:20
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加肥猪信息")
    @CommonLog("添加肥猪信息")
    @SaCheckPermission("/bi/pigfat/add")
    @PostMapping("/bi/pigfat/add")
    public CommonResult<String> add(@RequestBody @Valid PigFatAddParam pigFatAddParam) {
        pigFatService.add(pigFatAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑肥猪信息
     *
     * @author wang
     * @date  2023/12/18 09:20
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑肥猪信息")
    @CommonLog("编辑肥猪信息")
    @SaCheckPermission("/bi/pigfat/edit")
    @PostMapping("/bi/pigfat/edit")
    public CommonResult<String> edit(@RequestBody @Valid PigFatEditParam pigFatEditParam) {
        pigFatService.edit(pigFatEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除肥猪信息
     *
     * @author wang
     * @date  2023/12/18 09:20
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除肥猪信息")
    @CommonLog("删除肥猪信息")
    @SaCheckPermission("/bi/pigfat/delete")
    @PostMapping("/bi/pigfat/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                               CommonValidList<PigFatIdParam> pigFatIdParamList) {
        pigFatService.delete(pigFatIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取肥猪信息详情
     *
     * @author wang
     * @date  2023/12/18 09:20
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取肥猪信息详情")
    @SaCheckPermission("/bi/pigfat/detail")
    @GetMapping("/bi/pigfat/detail")
    public CommonResult<PigFat> detail(@Valid PigFatIdParam pigFatIdParam) {
        return CommonResult.data(pigFatService.detail(pigFatIdParam));
    }
}
