/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.bi.pigimmunity.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.common.pojo.CommonValidList;
import vip.xiaonuo.modular.bi.pigimmunity.entity.PigImmunity;
import vip.xiaonuo.modular.bi.pigimmunity.param.PigImmunityAddParam;
import vip.xiaonuo.modular.bi.pigimmunity.param.PigImmunityEditParam;
import vip.xiaonuo.modular.bi.pigimmunity.param.PigImmunityIdParam;
import vip.xiaonuo.modular.bi.pigimmunity.param.PigImmunityPageParam;
import vip.xiaonuo.modular.bi.pigimmunity.service.PigImmunityService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 免疫信息控制器
 *
 * @author wang
 * @date  2023/12/08 09:29
 */
@Api(tags = "免疫信息控制器")
@ApiSupport(author = "SNOWY_TEAM", order = 1)
@RestController
@Validated
public class PigImmunityController {

    @Resource
    private PigImmunityService pigImmunityService;

    /**
     * 获取免疫信息分页
     *
     * @author wang
     * @date  2023/12/08 09:29
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取免疫信息分页")
    @GetMapping("/bi/pigimmunity/page")
    public CommonResult<Page<PigImmunity>> page(PigImmunityPageParam pigImmunityPageParam) {
        return CommonResult.data(pigImmunityService.page(pigImmunityPageParam));
    }

    /**
     * 添加免疫信息
     *
     * @author wang
     * @date  2023/12/08 09:29
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加免疫信息")
    @CommonLog("添加免疫信息")
    @PostMapping("/bi/pigimmunity/add")
    public CommonResult<String> add(@RequestBody @Valid PigImmunityAddParam pigImmunityAddParam) {
        pigImmunityService.add(pigImmunityAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑免疫信息
     *
     * @author wang
     * @date  2023/12/08 09:29
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑免疫信息")
    @CommonLog("编辑免疫信息")
    @PostMapping("/bi/pigimmunity/edit")
    public CommonResult<String> edit(@RequestBody @Valid PigImmunityEditParam pigImmunityEditParam) {
        pigImmunityService.edit(pigImmunityEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除免疫信息
     *
     * @author wang
     * @date  2023/12/08 09:29
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除免疫信息")
    @CommonLog("删除免疫信息")
    @PostMapping("/bi/pigimmunity/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<PigImmunityIdParam> pigImmunityIdParamList) {
        pigImmunityService.delete(pigImmunityIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取免疫信息详情
     *
     * @author wang
     * @date  2023/12/08 09:29
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取免疫信息详情")
    @GetMapping("/bi/pigimmunity/detail")
    public CommonResult<PigImmunity> detail(@Valid PigImmunityIdParam pigImmunityIdParam) {
        return CommonResult.data(pigImmunityService.detail(pigImmunityIdParam));
    }
}
