/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.energy.energyWater.controller;

import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.auth.core.util.StpLoginUserUtil;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.modular.energy.energyElectricity.entity.vo.EnergyElectricityProportionVo;
import vip.xiaonuo.modular.energy.energyElectricity.entity.vo.EnergyElectricityTopVo;
import vip.xiaonuo.modular.energy.energyElectricity.entity.vo.EnergyElectricityTrendVo;
import vip.xiaonuo.modular.energy.energyElectricity.param.EnergyElectricityListParm;
import vip.xiaonuo.modular.energy.energyElectricity.param.EnergyElectricityProportionParam;
import vip.xiaonuo.modular.energy.energyElectricity.param.EnergyElectricityTopParm;
import vip.xiaonuo.modular.energy.energyWater.entity.EnergyWater;
import vip.xiaonuo.modular.energy.energyWater.entity.vo.EnergyWaterProportionVo;
import vip.xiaonuo.modular.energy.energyWater.entity.vo.EnergyWaterTopVo;
import vip.xiaonuo.modular.energy.energyWater.entity.vo.EnergyWaterTrendVo;
import vip.xiaonuo.modular.energy.energyWater.param.EnergyWaterListParm;
import vip.xiaonuo.modular.energy.energyWater.param.EnergyWaterProportionParam;
import vip.xiaonuo.modular.energy.energyWater.param.EnergyWaterTopParm;
import vip.xiaonuo.modular.energy.energyWater.service.EnergyWaterService;


import javax.annotation.Resource;
import java.util.List;

/**
 * 能耗水表控制器
 *
 * @author newspaper
 * @date  2023/12/21 09:15
 */
@Api(tags = "能耗水表控制器")
@ApiSupport(author = "HUIMV", order = 1)
@RestController
@Validated
public class EnergyWaterController {

    @Resource
    private EnergyWaterService energyWaterService;

    /**
     * 获取用水占比
     *
     * @author newspaper
     * @date  2023/12/21 09:15
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取用水占比")
    @GetMapping("/energy/energyWater/getProportion")
    public CommonResult<EnergyWaterProportionVo> getProportion(EnergyWaterProportionParam energyWaterProportionParam) {
        String type = energyWaterProportionParam.getType();
        String orgId = energyWaterProportionParam.getOrgId();
        return CommonResult.data(energyWaterService.getProportion(orgId,type));
    }

    /**
     * 获取用水量趋势
     *
     * @author newspaper
     * @date  2023/12/21 14:54
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("获取用水量趋势")
    @GetMapping("/energy/energyWater/listTrend")
    public CommonResult<EnergyWaterTrendVo> listTrend(EnergyWaterListParm energyWaterListParm) {
        return CommonResult.data(energyWaterService.listTrend(energyWaterListParm));
    }

    /**
     * 获取用水量排名
     *
     * @author newspaper
     * @date  2023/12/21 14:54
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("获取用水量排名")
    @GetMapping("/energy/energyWater/listTop")
    public CommonResult<List<EnergyWaterTopVo>> listTop(EnergyWaterTopParm energyWaterTopParm) {
        String orgId = energyWaterTopParm.getOrgId();
        return CommonResult.data(energyWaterService.listTop(energyWaterTopParm,orgId));
    }
}
