/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.feed.feedingenv.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.common.pojo.CommonValidList;
import vip.xiaonuo.modular.base.baseConfig.entity.BaseConfig;
import vip.xiaonuo.modular.env.envdevice.entity.EnvDevice;
import vip.xiaonuo.modular.env.envdevice.param.EnvDeviceOrgIdParam;
import vip.xiaonuo.modular.env.envdevice.param.EnvDevicePageParam;
import vip.xiaonuo.modular.feed.feedingenv.entity.FeedingEnv;
import vip.xiaonuo.modular.feed.feedingenv.param.*;
import vip.xiaonuo.modular.feed.feedingenv.service.FeedingEnvService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 精准饲喂设备控制器
 *
 * @author wang
 * @date  2023/12/28 11:26
 */
@Api(tags = "精准饲喂设备控制器")
@ApiSupport(author = "SNOWY_TEAM", order = 1)
@RestController
@Validated
public class FeedingEnvController {

    @Resource
    private FeedingEnvService feedingEnvService;

    /**
     * 获取精准饲喂设备分页
     *
     * @author wang
     * @date  2023/12/28 11:26
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取精准饲喂设备列表")
    @GetMapping("/feed/feedingenv/page")
    public CommonResult<List<FeedingEnv>> page(FeedingEnvPageParam feedingEnvPageParam) {
        return CommonResult.data(feedingEnvService.page(feedingEnvPageParam));
    }

    /**
     * 添加精准饲喂设备
     *
     * @author wang
     * @date  2023/12/28 11:26
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加精准饲喂设备")
    @CommonLog("添加精准饲喂设备")
    @PostMapping("/feed/feedingenv/add")
    public CommonResult<String> add(@RequestBody @Valid FeedingEnvAddParam feedingEnvAddParam) {
        return feedingEnvService.add(feedingEnvAddParam);
    }

    /**
     * 编辑精准饲喂设备
     *
     * @author wang
     * @date  2023/12/28 11:26
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑精准饲喂设备")
    @CommonLog("编辑精准饲喂设备")
    @PostMapping("/feed/feedingenv/edit")
    public CommonResult<String> edit(@RequestBody @Valid FeedingEnvEditParam feedingEnvEditParam) {
        return feedingEnvService.edit(feedingEnvEditParam);
    }

    /**
     * 删除精准饲喂设备
     *
     * @author wang
     * @date  2023/12/28 11:26
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除精准饲喂设备")
    @CommonLog("删除精准饲喂设备")
    @PostMapping("/feed/feedingenv/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                               CommonValidList<FeedingEnvIdParam> feedingEnvIdParamList) {
        feedingEnvService.delete(feedingEnvIdParamList);
        return CommonResult.ok();
    }

    /**
     * 设备汇总
     *
     * @author wang
     * @date  2023/12/28 11:26
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("设备汇总")
    @CommonLog("设备汇总")
    @PostMapping("/feed/feedingenv/listEnv")
    public CommonResult<JSONObject> listEnv(@RequestBody String orgId) {
        return CommonResult.data(feedingEnvService.listEnv(orgId));
    }


    @ApiOperationSupport(order = 6)
    @ApiOperation("获取精准饲喂设备分页")
    @GetMapping("/feed/feedingenv/listPage")
    public CommonResult<Page<FeedingEnv>> page1(FeedingEnvListParam envDevicePageParam) {
        return CommonResult.data(feedingEnvService.page(envDevicePageParam));
    }


    /**
     * 获取设备类型选择器
     *
     * @author newspaper
     * @date  2023/12/18 09:58
     */
    @ApiOperationSupport(order = 7)
    @ApiOperation("获取设备类型选择器")
    @GetMapping("/feed/feedingenv/deviceTypeSelector")
    public CommonResult<List<BaseConfig>> deviceTypeSelector(FeedingEnvPageParam envDeviceOrgIdParam) {
        return CommonResult.data(feedingEnvService.deviceTypeSelector(envDeviceOrgIdParam));
    }
}
